Struct authress::models::client_options::ClientOptions
source · pub struct ClientOptions {
pub grant_user_permissions_access: Option<Option<bool>>,
pub grant_token_generation: Option<Option<bool>>,
}Expand description
ClientOptions : A set of client specific options
Fields
grant_user_permissions_access: Option<Option<bool>>Grant the client access to verify authorization on behalf of any user.
grant_token_generation: Option<Option<bool>>Grant the client access to generate oauth tokens on behalf of the Authress account. Security Warning: This means that this client can impersonate any user, and should only be used when connecting an existing custom Authorization Server to Authress, when that server does not support a standard OAuth connection.
Implementations
sourceimpl ClientOptions
impl ClientOptions
sourcepub fn new() -> ClientOptions
pub fn new() -> ClientOptions
A set of client specific options