Identity

Struct Identity 

pub struct Identity {
    pub issuer: String,
    pub audience: String,
}
Identity : The identifying information which uniquely links a JWT OIDC token to an identity provider

Fields

issuer: String

The issuer of the JWT token. This can be any OIDC compliant provider.

audience: String

The audience of the JWT token. This can be either an audience for your entire app, or one particular audience for it. If there is more than one audience, multiple identities can be created.

Implementations

Source

impl Identity

pub fn new(issuer: String, audience: String) -> Identity

The identifying information which uniquely links a JWT OIDC token to an identity provider