pub struct Identity {
pub issuer: String,
pub audience: String,
}Expand description
Identity : The identifying information which uniquely links a JWT OIDC token to an identity provider
Fields
issuer: StringThe issuer of the JWT token. This can be any OIDC compliant provider.
audience: StringThe audience of the JWT token. This can be either an audience for your entire app, or one particular audience for it. If there is more than one audience, multiple identities can be created.
Implementations